==> myfaces-core-assembly-2.0.25-src.zip: javax/faces/event/ActionEvent.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package javax.faces.event;

import javax.faces.component.UIComponent;

/**
 * see Javadoc of <a href="http://java.sun.com/javaee/javaserverfaces/1.2/docs/api/index.html">JSF Specification</a>
 * 
 * @author Thomas Spiegl (latest modification by $Author$)
 * @version $Revision$ $Date$
 */
public class ActionEvent extends FacesEvent
{
    private static final long serialVersionUID = 3693030212414392259L;

    public ActionEvent(UIComponent uiComponent)
    {
        super(uiComponent);
        if (uiComponent == null)
        {
            throw new IllegalArgumentException("uiComponent");
        }
    }

    @Override
    public boolean isAppropriateListener(FacesListener facesListeners)
    {
        return facesListeners instanceof ActionListener;
    }

    @Override
    public void processListener(FacesListener facesListeners)
    {
        ((ActionListener)facesListeners).processAction(this);
    }

}

==> myfaces-core-assembly-2.3.10-src.zip: javax/faces/event/ActionEvent.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package javax.faces.event;

import javax.faces.component.UIComponent;
import javax.faces.context.FacesContext;

/**
 * see Javadoc of <a href="http://java.sun.com/javaee/javaserverfaces/1.2/docs/api/index.html">JSF Specification</a>
 */
public class ActionEvent extends FacesEvent
{
    private static final long serialVersionUID = 3693030212414392259L;

    public ActionEvent(FacesContext facesContext, UIComponent uiComponent)
    {
        super(facesContext, uiComponent);
        if (uiComponent == null)
        {
            throw new IllegalArgumentException("uiComponent");
        }
    }

    public ActionEvent(UIComponent uiComponent)
    {
        super(uiComponent);
        if (uiComponent == null)
        {
            throw new IllegalArgumentException("uiComponent");
        }
    }

    @Override
    public boolean isAppropriateListener(FacesListener facesListeners)
    {
        return facesListeners instanceof ActionListener;
    }

    @Override
    public void processListener(FacesListener facesListeners)
    {
        ((ActionListener)facesListeners).processAction(this);
    }

}
